@@ -168,8 +168,10 @@ void KateConfigInterfaceTest::testView()
     view->setConfigValue(QStringLiteral("scrollbar-preview"), false);
     QCOMPARE(view->configValue(QLatin1String("scrollbar-preview")).toBool(), false);
 
-    view->setConfigValue(QStringLiteral("font"), QFont(QStringLiteral("Times"), 10, QFont::Bold));
-    QCOMPARE(view->configValue(QLatin1String("font")).value<QFont>(), QFont(QStringLiteral("Times"), 10, QFont::Bold));
+    QFont f(QStringLiteral("Times"), 10, QFont::Bold);
+    f.setHintingPreference(QFont::PreferFullHinting);
+    view->setConfigValue(QStringLiteral("font"), f);
+    QCOMPARE(view->configValue(QLatin1String("font")).value<QFont>(), f);
 
     {
         KSyntaxHighlighting::Repository &repository = KTextEditor::EditorPrivate::self()->hlManager()->repository();
