@@ -1,22 +1,9 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2013 Dominik Haumann <dhaumann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the Kate project.
+    SPDX-FileCopyrightText: 2013 Dominik Haumann <dhaumann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "messagetest.h"
 
@@ -48,9 +35,8 @@ void MessageTest::testPostMessage()
     KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(view));
 
-    QPointer<Message> message = new Message("Message text", Message::Information);
+    QPointer<Message> message = new Message(QStringLiteral("Message text"), Message::Information);
     message->setPosition(Message::TopInView);
 
     // posing message should succeed
@@ -65,7 +51,7 @@ void MessageTest::testPostMessage()
 
     QVERIFY(message != nullptr);
     delete message;
-    QTest::qWait(600); // fadeout animation takes 500 ms
+    QTest::qWait(1000); // fadeout animation takes 500 ms
     QVERIFY(!view->messageWidget()->isVisible());
 }
 
@@ -76,13 +62,12 @@ void MessageTest::testAutoHide()
     KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(view));
 
     //
     // show a message with autoHide. Check, if it's deleted correctly
     // auto hide mode: Message::Immediate
     //
-    QPointer<Message> message = new Message("Message text", Message::Information);
+    QPointer<Message> message = new Message(QStringLiteral("Message text"), Message::Information);
     message->setPosition(Message::TopInView);
     message->setAutoHide(1000);
     message->setAutoHideMode(Message::Immediate);
@@ -108,14 +93,12 @@ void MessageTest::testAutoHideAfterUserInteraction()
     KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(view));
-    QTest::qWait(1000);
 
     //
     // show a message with autoHide. Check, if it's deleted correctly
     // auto hide mode: Message::AfterUserInteraction
     //
-    QPointer<Message> message = new Message("Message text", Message::Information);
+    QPointer<Message> message = new Message(QStringLiteral("Message text"), Message::Information);
     message->setPosition(Message::TopInView);
     message->setAutoHide(2000);
     QVERIFY(message->autoHideMode() == Message::AfterUserInteraction);
@@ -126,7 +109,7 @@ void MessageTest::testAutoHideAfterUserInteraction()
     QVERIFY(view->messageWidget()->isVisible());
 
     // now trigger user interaction after 1 second
-    view->insertText("Hello world");
+    view->insertText(QStringLiteral("Hello world"));
     view->setCursorPosition(Cursor(0, 5));
 
     // should still be there after deleted after another 1.9 seconds
@@ -134,13 +117,13 @@ void MessageTest::testAutoHideAfterUserInteraction()
     QVERIFY(message.data() != nullptr);
     QVERIFY(view->messageWidget()->isVisible());
 
-    // another 200ms later: 3.1 seconds are gone, message should be deleted
+    // another 300ms later: 3.2 seconds are gone, message should be deleted
     // and fade animation should be active
-    QTest::qWait(200);
+    QTest::qWait(300);
     QVERIFY(message.data() == nullptr);
     QVERIFY(view->messageWidget()->isVisible());
 
-    // after a total of 3.6 seconds, widget should be hidden
+    // after a total of 3.7 seconds, widget should be hidden
     QTest::qWait(500);
     QVERIFY(!view->messageWidget()->isVisible());
 }
@@ -152,19 +135,17 @@ void MessageTest::testMessageQueue()
     KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(view));
-    QTest::qWait(1000);
 
     //
     // add two messages, both with autoHide to 1 second, and check that the queue is processed correctly
     // auto hide mode: Message::Immediate
     //
-    QPointer<Message> m1 = new Message("Info text", Message::Information);
+    QPointer<Message> m1 = new Message(QStringLiteral("Info text"), Message::Information);
     m1->setPosition(Message::TopInView);
     m1->setAutoHide(1000);
     m1->setAutoHideMode(Message::Immediate);
 
-    QPointer<Message> m2 = new Message("Error text", Message::Error);
+    QPointer<Message> m2 = new Message(QStringLiteral("Error text"), Message::Error);
     m2->setPosition(Message::TopInView);
     m2->setAutoHide(1000);
     m2->setAutoHideMode(Message::Immediate);
@@ -210,8 +191,6 @@ void MessageTest::testPriority()
     KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(view));
-    QTest::qWait(1000);
 
     //
     // add two messages
@@ -221,11 +200,11 @@ void MessageTest::testPriority()
     // - m1 should be hidden in favour of m2
     // - changing text of m1 while m2 is displayed should not change the displayed text
     //
-    QPointer<Message> m1 = new Message("m1", Message::Positive);
+    QPointer<Message> m1 = new Message(QStringLiteral("m1"), Message::Positive);
     m1->setPosition(Message::TopInView);
     QVERIFY(m1->priority() == 0);
 
-    QPointer<Message> m2 = new Message("m2", Message::Error);
+    QPointer<Message> m2 = new Message(QStringLiteral("m2"), Message::Error);
     m2->setPosition(Message::TopInView);
     m2->setAutoHide(1000);
     m2->setAutoHideMode(Message::Immediate);
@@ -238,7 +217,7 @@ void MessageTest::testPriority()
     // after 1s, message should be displayed
     QTest::qWait(1000);
     QVERIFY(view->messageWidget()->isVisible());
-    QCOMPARE(view->messageWidget()->text(), QString("m1"));
+    QCOMPARE(view->messageWidget()->text(), QStringLiteral("m1"));
     QVERIFY(m1.data() != nullptr);
 
     // post m2, m1 should be hidden, and m2 visible
@@ -247,11 +226,11 @@ void MessageTest::testPriority()
 
     // alter text of m1 when m2 is visible, shouldn't influence m2
     QTest::qWait(600);
-    m1->setText("m1 changed");
+    m1->setText(QStringLiteral("m1 changed"));
 
     // after 0.7 seconds, m2 is visible
     QTest::qWait(100);
-    QCOMPARE(view->messageWidget()->text(), QString("m2"));
+    QCOMPARE(view->messageWidget()->text(), QStringLiteral("m2"));
     QVERIFY(m2.data() != nullptr);
 
     // after 1.6 seconds, m2 is hidden again and m1 is visible again
@@ -262,7 +241,7 @@ void MessageTest::testPriority()
 
     // finally check m1 again
     QTest::qWait(1000);
-    QCOMPARE(view->messageWidget()->text(), QString("m1 changed"));
+    QCOMPARE(view->messageWidget()->text(), QStringLiteral("m1 changed"));
 }
 
 void MessageTest::testCreateView()
@@ -277,7 +256,7 @@ void MessageTest::testCreateView()
     // - verify that both views get the message
     // - verify that, once the message is deleted, both views hide the message
     //
-    QPointer<Message> m1 = new Message("message", Message::Positive);
+    QPointer<Message> m1 = new Message(QStringLiteral("message"), Message::Positive);
     m1->setPosition(Message::TopInView);
     QVERIFY(m1->priority() == 0);
 
@@ -291,15 +270,12 @@ void MessageTest::testCreateView()
     v2->show();
     v1->resize(400, 300);
     v2->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(v1));
-    QVERIFY(QTest::qWaitForWindowExposed(v2));
-    QTest::qWait(1000);
 
     // make sure both views show the message
     QVERIFY(v1->messageWidget()->isVisible());
     QVERIFY(v2->messageWidget()->isVisible());
-    QCOMPARE(v1->messageWidget()->text(), QString("message"));
-    QCOMPARE(v2->messageWidget()->text(), QString("message"));
+    QCOMPARE(v1->messageWidget()->text(), QStringLiteral("message"));
+    QCOMPARE(v2->messageWidget()->text(), QStringLiteral("message"));
     QVERIFY(m1.data() != nullptr);
 
     // delete message, then check after fadeout time 0f 0.5s whether message is gone
@@ -316,11 +292,9 @@ void MessageTest::testHideView()
     KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(view));
-    QTest::qWait(1000);
 
     // create message that hides after 2s immediately
-    QPointer<Message> message = new Message("Message text", Message::Information);
+    QPointer<Message> message = new Message(QStringLiteral("Message text"), Message::Information);
     message->setAutoHide(2000);
     message->setAutoHideMode(Message::Immediate);
     message->setPosition(Message::TopInView);
@@ -336,19 +310,19 @@ void MessageTest::testHideView()
     //
     QTest::qWait(1100);
     QVERIFY(view->messageWidget()->isVisible());
-    QCOMPARE(view->messageWidget()->text(), QString("Message text"));
+    QCOMPARE(view->messageWidget()->text(), QStringLiteral("Message text"));
 
     // hide view
     view->hide();
 
-    // wait 1s, message should be null (after total of 2100 ms)
-    QTest::qWait(1000);
+    // wait 1s, message should be null (after total of 2200 ms)
+    QTest::qWait(1100);
     QVERIFY(message.data() == nullptr);
 
-    // show view again, message contents should be fading for the lasting 400 ms
+    // show view again, message contents should be fading for the lasting 300 ms
     view->show();
     QVERIFY(view->messageWidget()->isVisible());
-    QCOMPARE(view->messageWidget()->text(), QString("Message text"));
+    QCOMPARE(view->messageWidget()->text(), QStringLiteral("Message text"));
 
     // wait another 0.5s, then message widget should be hidden
     QTest::qWait(500);
@@ -363,11 +337,9 @@ void MessageTest::testHideViewAfterUserInteraction()
     KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
     view->show();
     view->resize(400, 300);
-    QVERIFY(QTest::qWaitForWindowExposed(view));
-    QTest::qWait(1000);
 
     // create message that hides after 2s immediately
-    QPointer<Message> message = new Message("Message text", Message::Information);
+    QPointer<Message> message = new Message(QStringLiteral("Message text"), Message::Information);
     message->setAutoHide(2000);
     QVERIFY(message->autoHideMode() == Message::AfterUserInteraction);
     message->setPosition(Message::TopInView);
@@ -383,7 +355,7 @@ void MessageTest::testHideViewAfterUserInteraction()
     //
     QTest::qWait(1500);
     QVERIFY(view->messageWidget()->isVisible());
-    QCOMPARE(view->messageWidget()->text(), QString("Message text"));
+    QCOMPARE(view->messageWidget()->text(), QStringLiteral("Message text"));
 
     // hide view
     view->hide();
@@ -398,14 +370,14 @@ void MessageTest::testHideViewAfterUserInteraction()
     //
     view->show();
     QTest::qWait(2000);
-    view->insertText("Hello world");
+    view->insertText(QStringLiteral("Hello world"));
     view->setCursorPosition(Cursor(0, 5));
 
     // wait 1.5s and check that message is still displayed
     QTest::qWait(1500);
     QVERIFY(message.data() != nullptr);
     QVERIFY(view->messageWidget()->isVisible());
-    QCOMPARE(view->messageWidget()->text(), QString("Message text"));
+    QCOMPARE(view->messageWidget()->text(), QStringLiteral("Message text"));
 
     // wait another 0.8s, then the message is deleted
     QTest::qWait(800);
@@ -416,3 +388,5 @@ void MessageTest::testHideViewAfterUserInteraction()
     QTest::qWait(600);
     QVERIFY(!view->messageWidget()->isVisible());
 }
+
+#include "moc_messagetest.cpp"
