@@ -18,18 +18,35 @@
 #include <ktexteditor/message.h>
 #include <ktexteditor/movingcursor.h>
 
+#include <QApplication>
+#include <QKeyEvent>
+#include <QMouseEvent>
 #include <QTest>
 
 using namespace KTextEditor;
 
-#define CREATE_VIEW_AND_DOC(text, line, col)                                          \
-    KTextEditor::DocumentPrivate doc(false, false);                                   \
-    doc.setText(text);                                                                \
-    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);     \
-    view->setCursorPosition({line, col})
-
 QTEST_MAIN(MulticursorTest)
 
+struct DocAndView {
+    DocumentPrivate *doc;
+    ViewPrivate *view;
+
+    ~DocAndView()
+    {
+        delete view;
+        delete doc;
+    }
+};
+
+DocAndView createDocAndView(const QString &text, int line, int column)
+{
+    auto doc = new DocumentPrivate();
+    doc->setText(text);
+    auto view = new ViewPrivate(doc, nullptr);
+    view->setCursorPosition({line, column});
+    return {doc, view};
+}
+
 template<typename Cont>
 bool isSorted(const Cont &c)
 {
@@ -56,18 +73,18 @@ static QWidget *findViewInternal(KTextEditor::ViewPrivate *view)
     return nullptr;
 }
 
-static void clickAtPosition(ViewPrivate *view, QObject *internalView, Cursor pos, Qt::KeyboardModifiers m)
+static void clickAtPosition(ViewPrivate *view, QWidget *internalView, Cursor pos, Qt::KeyboardModifiers m)
 {
     QPoint p = view->cursorToCoordinate(pos);
     QVERIFY(p.x() >= 0 && p.y() >= 0);
-    auto me = QMouseEvent(QEvent::MouseButtonPress, p, Qt::LeftButton, Qt::LeftButton, m);
+    auto me = QMouseEvent(QEvent::MouseButtonPress, p, internalView->mapToGlobal(p), Qt::LeftButton, Qt::LeftButton, m);
     QCoreApplication::sendEvent(internalView, &me);
 }
 
 void MulticursorTest::testKillline()
 {
     KTextEditor::DocumentPrivate doc;
-    doc.insertLines(0, {"foo", "bar", "baz"});
+    doc.insertLines(0, {QStringLiteral("foo"), QStringLiteral("bar"), QStringLiteral("baz")});
     KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
     view->setCursorPositionInternal(KTextEditor::Cursor(0, 0));
     view->addSecondaryCursor(KTextEditor::Cursor(1, 0));
@@ -81,7 +98,7 @@ void MulticursorTest::testKillline()
 
 void MulticursorTest::insertRemoveText()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\n", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\n"), 0, 0);
     QObject *internalView = findViewInternal(view);
     QVERIFY(internalView);
 
@@ -94,11 +111,11 @@ void MulticursorTest::insertRemoveText()
         QKeyEvent ke(QKeyEvent::KeyPress, Qt::Key_L, Qt::NoModifier, QStringLiteral("L"));
         QCoreApplication::sendEvent(internalView, &ke);
 
-        QCOMPARE(doc.line(0), QStringLiteral("LfLoLoL"));
+        QCOMPARE(doc->line(0), QStringLiteral("LfLoLoL"));
 
         // Removal
         view->backspace();
-        QCOMPARE(doc.line(0), QStringLiteral("foo"));
+        QCOMPARE(doc->line(0), QStringLiteral("foo"));
 
         view->clearSecondaryCursors();
     }
@@ -110,23 +127,23 @@ void MulticursorTest::insertRemoveText()
         QKeyEvent ke(QKeyEvent::KeyPress, Qt::Key_L, Qt::NoModifier, QStringLiteral("L"));
         QCoreApplication::sendEvent(internalView, &ke);
 
-        QCOMPARE(doc.line(0), QStringLiteral("Lfoo"));
-        QCOMPARE(doc.line(1), QStringLiteral("Lbar"));
-        QCOMPARE(doc.line(2), QStringLiteral("Lfoo"));
+        QCOMPARE(doc->line(0), QStringLiteral("Lfoo"));
+        QCOMPARE(doc->line(1), QStringLiteral("Lbar"));
+        QCOMPARE(doc->line(2), QStringLiteral("Lfoo"));
 
         view->backspace();
         QVERIFY(isSorted(view->secondaryCursors()));
 
-        QCOMPARE(doc.line(0), QStringLiteral("foo"));
-        QCOMPARE(doc.line(1), QStringLiteral("bar"));
-        QCOMPARE(doc.line(2), QStringLiteral("foo"));
+        QCOMPARE(doc->line(0), QStringLiteral("foo"));
+        QCOMPARE(doc->line(1), QStringLiteral("bar"));
+        QCOMPARE(doc->line(2), QStringLiteral("foo"));
 
         QVERIFY(isSorted(view->secondaryCursors()));
         view->clearSecondaryCursors();
     }
 
     // Three empty lines
-    doc.setText(QStringLiteral("\n\n\n"));
+    doc->setText(QStringLiteral("\n\n\n"));
     view->setCursorPosition({0, 0});
     view->addSecondaryCursor({1, 0});
     view->addSecondaryCursor({2, 0});
@@ -140,8 +157,8 @@ void MulticursorTest::insertRemoveText()
 
 void MulticursorTest::backspace()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nbaz", 0, 3);
-    QVector<KTextEditor::ViewPrivate::PlainSecondaryCursor> cursors;
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nbaz"), 0, 3);
+    QList<KTextEditor::ViewPrivate::PlainSecondaryCursor> cursors;
 
     {
         // Mixed cursors, one doesn't have selection
@@ -153,31 +170,31 @@ void MulticursorTest::backspace()
         // Pressing backspace should only remove selected text
         view->backspace();
         QVERIFY(isSorted(view->secondaryCursors()));
-        QCOMPARE(doc.text(), QStringLiteral("foo\n\n"));
+        QCOMPARE(doc->text(), QStringLiteral("foo\n\n"));
 
         // Pressing backspace again
         view->backspace();
         QVERIFY(view->secondaryCursors().empty());
-        QCOMPARE(doc.text(), QStringLiteral("fo"));
+        QCOMPARE(doc->text(), QStringLiteral("fo"));
     }
 
     {
         // No selection
-        doc.setText("foo\nbar\nbaz");
+        doc->setText(QStringLiteral("foo\nbar\nbaz"));
         view->setCursors({Cursor(0, 3), Cursor(1, 3), Cursor(2, 3)});
         view->backspace();
-        QCOMPARE(doc.text(), QStringLiteral("fo\nba\nba"));
+        QCOMPARE(doc->text(), QStringLiteral("fo\nba\nba"));
         view->backspace();
         view->backspace();
-        QCOMPARE(doc.text(), QStringLiteral("\n\n"));
+        QCOMPARE(doc->text(), QStringLiteral("\n\n"));
         QCOMPARE(view->cursors().size(), 3);
     }
 }
 
 void MulticursorTest::keyDelete()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nbaz", 0, 0);
-    QVector<KTextEditor::ViewPrivate::PlainSecondaryCursor> cursors;
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nbaz"), 0, 0);
+    QList<KTextEditor::ViewPrivate::PlainSecondaryCursor> cursors;
 
     {
         // Mixed cursors, one doesn't have selection
@@ -189,79 +206,79 @@ void MulticursorTest::keyDelete()
         // Pressing del should only remove selected text
         view->keyDelete();
         QVERIFY(isSorted(view->secondaryCursors()));
-        QCOMPARE(doc.text(), QStringLiteral("foo\n\n"));
+        QCOMPARE(doc->text(), QStringLiteral("foo\n\n"));
 
         // Pressing del again
         view->keyDelete();
         QCOMPARE(view->secondaryCursors().size(), 1);
-        QCOMPARE(doc.text(), QStringLiteral("oo\n"));
+        QCOMPARE(doc->text(), QStringLiteral("oo\n"));
     }
 
     {
         // No selection
-        doc.setText("foo\nbar\nbaz");
+        doc->setText(QStringLiteral("foo\nbar\nbaz"));
         view->setCursors({Cursor(0, 0), Cursor(1, 0), Cursor(2, 0)});
         view->keyDelete();
-        QCOMPARE(doc.text(), QStringLiteral("oo\nar\naz"));
+        QCOMPARE(doc->text(), QStringLiteral("oo\nar\naz"));
         view->keyDelete();
         view->keyDelete();
-        QCOMPARE(doc.text(), QStringLiteral("\n\n"));
+        QCOMPARE(doc->text(), QStringLiteral("\n\n"));
         QCOMPARE(view->cursors().size(), 3);
     }
 }
 
 void MulticursorTest::testUndoRedo()
 {
-    CREATE_VIEW_AND_DOC("foo\nfoo", 0, 3);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo"), 0, 3);
 
     // single cursor backspace
     view->backspace();
-    QCOMPARE(doc.text(), QStringLiteral("fo\nfoo"));
-    doc.undoManager()->undoSafePoint();
+    QCOMPARE(doc->text(), QStringLiteral("fo\nfoo"));
+    doc->undoManager()->undoSafePoint();
 
     // backspace with 2 cursors
     view->setCursors({view->cursorPosition(), Cursor{1, 3}});
     view->backspace();
-    QCOMPARE(doc.text(), QStringLiteral("f\nfo"));
+    QCOMPARE(doc->text(), QStringLiteral("f\nfo"));
 
     view->doc()->undo();
-    QCOMPARE(doc.text(), QStringLiteral("fo\nfoo"));
+    QCOMPARE(doc->text(), QStringLiteral("fo\nfoo"));
     QCOMPARE(view->secondaryCursors().size(), 1);
     QCOMPARE(*view->secondaryCursors().at(0).pos, Cursor(1, 3));
 
     // Another undo, multicursor should be gone
     view->doc()->undo();
-    QCOMPARE(doc.text(), QStringLiteral("foo\nfoo"));
+    QCOMPARE(doc->text(), QStringLiteral("foo\nfoo"));
     QCOMPARE(view->secondaryCursors().size(), 0);
 
     // One redo
     view->doc()->redo();
-    QCOMPARE(doc.text(), QStringLiteral("fo\nfoo"));
+    QCOMPARE(doc->text(), QStringLiteral("fo\nfoo"));
 
     // Second redo, multicursor should be back
     view->doc()->redo();
-    QCOMPARE(doc.text(), QStringLiteral("f\nfo"));
+    QCOMPARE(doc->text(), QStringLiteral("f\nfo"));
     QCOMPARE(view->secondaryCursors().size(), 1);
     QCOMPARE(*view->secondaryCursors().at(0).pos, Cursor(1, 2));
 }
 
 void MulticursorTest::testUndoRedoWithSelection()
 {
-    CREATE_VIEW_AND_DOC("foo\nfoo", 0, 3);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo"), 0, 3);
     view->setCursors({Cursor(0, 3), Cursor(1, 3)});
 
     // select a word & remove it
     view->shiftWordLeft();
     view->backspace();
 
-    QCOMPARE(doc.text(), QStringLiteral("\n"));
+    QCOMPARE(doc->text(), QStringLiteral("\n"));
     QCOMPARE(view->cursorPosition(), Cursor(0, 0));
     QCOMPARE(view->secondaryCursors().size(), 1);
     QCOMPARE(*view->secondaryCursors().at(0).pos, Cursor(1, 0));
 
     view->doc()->undo();
 
-    QCOMPARE(doc.text(), QStringLiteral("foo\nfoo"));
+    QCOMPARE(doc->text(), QStringLiteral("foo\nfoo"));
     QCOMPARE(view->cursorPosition(), Cursor(0, 0));
     QCOMPARE(view->secondaryCursors().size(), 1);
     QCOMPARE(*view->secondaryCursors().at(0).pos, Cursor(1, 0));
@@ -271,9 +288,9 @@ void MulticursorTest::testUndoRedoWithSelection()
 
 void MulticursorTest::keyReturnIndentTest()
 {
-    CREATE_VIEW_AND_DOC("\n\n", 0, 0);
-    QCOMPARE(doc.lines(), 3);
-    doc.setMode(QStringLiteral("C++"));
+    auto [doc, view] = createDocAndView(QStringLiteral("\n\n"), 0, 0);
+    QCOMPARE(doc->lines(), 3);
+    doc->setMode(QStringLiteral("C++"));
     view->config()->setValue(KateViewConfig::AutoBrackets, true);
 
     view->addSecondaryCursorDown();
@@ -281,46 +298,46 @@ void MulticursorTest::keyReturnIndentTest()
     QCOMPARE(view->secondaryCursors().size(), 2);
     QVERIFY(isSorted(view->secondaryCursors()));
 
-    doc.typeChars(view, QStringLiteral("{"));
-    QCOMPARE(doc.text(), QStringLiteral("{}\n{}\n{}"));
+    doc->typeChars(view, QStringLiteral("{"));
+    QCOMPARE(doc->text(), QStringLiteral("{}\n{}\n{}"));
     QCOMPARE(view->secondaryCursors().size(), 2);
     QVERIFY(isSorted(view->secondaryCursors()));
 
     view->keyReturn();
-    QCOMPARE(doc.text(), QStringLiteral("{\n    \n}\n{\n    \n}\n{\n    \n}"));
+    QCOMPARE(doc->text(), QStringLiteral("{\n    \n}\n{\n    \n}\n{\n    \n}"));
 }
 
 void MulticursorTest::wrapSelectionWithCharsTest()
 {
-    CREATE_VIEW_AND_DOC("foo\nfoo\nfoo", 0, 3);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo"), 0, 3);
 
     view->addSecondaryCursorDown();
     view->addSecondaryCursorDown();
     QCOMPARE(view->secondaryCursors().size(), 2);
 
     view->shiftWordLeft();
-    doc.typeChars(view, QStringLiteral("{"));
-    QCOMPARE(doc.text(), QStringLiteral("{foo}\n{foo}\n{foo}"));
+    doc->typeChars(view, QStringLiteral("{"));
+    QCOMPARE(doc->text(), QStringLiteral("{foo}\n{foo}\n{foo}"));
 }
 
 void MulticursorTest::insertAutoBrackets()
 {
-    CREATE_VIEW_AND_DOC("hello\nhello", 0, 0);
-    QCOMPARE(doc.lines(), 2);
-    doc.setMode(QStringLiteral("C++"));
+    auto [doc, view] = createDocAndView(QStringLiteral("hello\nhello"), 0, 0);
+    QCOMPARE(doc->lines(), 2);
+    doc->setMode(QStringLiteral("C++"));
     view->config()->setValue(KateViewConfig::AutoBrackets, true);
     view->setSecondaryCursors({Cursor(0, 0), Cursor(1, 0)});
     QCOMPARE(view->cursors().size(), 2);
 
-    doc.typeChars(view, QStringLiteral("("));
-    QCOMPARE(doc.text(), QStringLiteral("(hello\n(hello"));
+    doc->typeChars(view, QStringLiteral("("));
+    QCOMPARE(doc->text(), QStringLiteral("(hello\n(hello"));
 }
 
 void MulticursorTest::testCreateMultiCursor()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\n", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\n"), 0, 0);
 
-    QObject *internalView = findViewInternal(view);
+    auto *internalView = findViewInternal(view);
     QVERIFY(internalView);
 
     // Alt + click should add a cursor
@@ -350,7 +367,7 @@ void MulticursorTest::testCreateMultiCursor()
 
 void MulticursorTest::testCreateMultiCursorFromSelection()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo", 2, 3);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo"), 2, 3);
     view->setSelection(KTextEditor::Range(0, 0, 2, 3));
     // move primary cursor to beginning of line, so we can check whether it is moved to end of line
     view->setCursorPosition({view->cursorPosition().line(), 0});
@@ -359,7 +376,7 @@ void MulticursorTest::testCreateMultiCursorFromSelection()
     QCOMPARE(view->cursorPosition().column(), 3);
 
     const auto &cursors = view->secondaryCursors();
-    QCOMPARE(cursors.size(), doc.lines() - 1); // 1 cursor is primary, not included
+    QCOMPARE(cursors.size(), doc->lines() - 1); // 1 cursor is primary, not included
 
     int i = 0;
     for (const auto &c : cursors) {
@@ -370,7 +387,7 @@ void MulticursorTest::testCreateMultiCursorFromSelection()
 
 void MulticursorTest::testMulticursorToggling()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo"), 0, 0);
     view->setSelections({Range(0, 0, 0, 3), Range(1, 0, 1, 3)});
     QCOMPARE(view->selectionRanges().size(), 2);
 
@@ -386,7 +403,7 @@ void MulticursorTest::testMulticursorToggling()
 
 void MulticursorTest::moveCharTest()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\n", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\n"), 0, 0);
     view->setCursors({Cursor(0, 0), Cursor(1, 0)});
 
     // Simple left right
@@ -435,7 +452,7 @@ void MulticursorTest::moveCharTest()
 
 void MulticursorTest::moveCharInFirstOrLastLineTest()
 {
-    CREATE_VIEW_AND_DOC("foo", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo"), 0, 0);
     view->addSecondaryCursor({0, 1});
     // |f|oo
 
@@ -452,7 +469,7 @@ void MulticursorTest::moveCharInFirstOrLastLineTest()
 
 void MulticursorTest::moveWordTest()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\n", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\n"), 0, 0);
     view->setCursors({Cursor(0, 0), Cursor(1, 0)});
 
     // Simple left right
@@ -496,7 +513,7 @@ void MulticursorTest::moveWordTest()
 
 void MulticursorTest::homeEndKeyTest()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\n", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\n"), 0, 0);
     view->setCursors({Cursor(0, 0), Cursor(0, 1)});
 
     // Two cursor in same line => home should merge them
@@ -526,7 +543,7 @@ void MulticursorTest::homeEndKeyTest()
 void MulticursorTest::moveUpDown()
 {
     /** TEST UP **/
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo"), 0, 0);
 
     view->setSecondaryCursors({Cursor(1, 0), Cursor(2, 0)});
     QCOMPARE(view->secondaryCursors().size(), 2);
@@ -561,7 +578,7 @@ void MulticursorTest::testSelectionMerge()
     // 8 lines
     {
         // Left movement, cursor at top
-        CREATE_VIEW_AND_DOC("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo", 0, 3);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo"), 0, 3);
 
         view->selectAll();
         view->createMultiCursorsFromSelection();
@@ -582,7 +599,7 @@ void MulticursorTest::testSelectionMerge()
 
     {
         // Left movement, cursor at bottom
-        CREATE_VIEW_AND_DOC("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo", 6, 3);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo"), 6, 3);
 
         view->selectAll();
         view->createMultiCursorsFromSelection();
@@ -604,7 +621,7 @@ void MulticursorTest::testSelectionMerge()
 
     {
         // Left word movement, cursor in the middle
-        CREATE_VIEW_AND_DOC("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo", 3, 3);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo"), 3, 3);
 
         for (int i = 0; i < 10; ++i) {
             view->addSecondaryCursorUp();
@@ -624,7 +641,7 @@ void MulticursorTest::testSelectionMerge()
 
     {
         // Left word + char movement, cursor in the middle
-        CREATE_VIEW_AND_DOC("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo", 3, 3);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo"), 3, 3);
 
         view->addSecondaryCursorUp();
         view->addSecondaryCursorUp();
@@ -646,7 +663,7 @@ void MulticursorTest::testSelectionMerge()
 
     {
         // Right movement, cursor at bottom line
-        CREATE_VIEW_AND_DOC("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo", 6, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo"), 6, 0);
 
         for (int i = 0; i < 10; ++i) {
             view->addSecondaryCursorUp();
@@ -667,7 +684,7 @@ void MulticursorTest::testSelectionMerge()
 
     {
         // Right movement, cursor at top line
-        CREATE_VIEW_AND_DOC("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo"), 0, 0);
 
         for (int i = 0; i < 10; ++i) {
             view->addSecondaryCursorDown();
@@ -686,7 +703,7 @@ void MulticursorTest::testSelectionMerge()
 
     {
         // Right word + char movement, cursor in the middle
-        CREATE_VIEW_AND_DOC("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo", 3, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nfoo\nfoo\nfoo\nfoo\nfoo\nfoo"), 3, 0);
 
         view->addSecondaryCursorUp();
         view->addSecondaryCursorUp();
@@ -712,7 +729,7 @@ void MulticursorTest::testSelectionMerge()
 
 void MulticursorTest::findNextOccurenceTest()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\nfoo", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\nfoo"), 0, 0);
 
     // No selection
     view->findNextOccurunceAndSelect();
@@ -753,7 +770,7 @@ void MulticursorTest::findNextOccurenceTest()
 
 void MulticursorTest::findAllOccurenceTest()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\nfoo", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\nfoo"), 0, 0);
 
     // No selection
     view->findAllOccuruncesAndSelect();
@@ -777,7 +794,7 @@ void MulticursorTest::testMultiCopyPaste()
 {
     // Create two docs, copy from one to the other
     {
-        CREATE_VIEW_AND_DOC("foo\nbar\nfoo\nfoo", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\nfoo"), 0, 0);
         view->addSecondaryCursor({1, 0});
         view->addSecondaryCursor({2, 0});
         view->addSecondaryCursor({3, 0});
@@ -788,7 +805,7 @@ void MulticursorTest::testMultiCopyPaste()
     // Same number of cursors when pasting => each line gets pasted into matching cursor postion
     {
         KTextEditor::DocumentPrivate doc;
-        doc.setText("\n\n\n\n");
+        doc.setText(QStringLiteral("\n\n\n\n"));
         KTextEditor::ViewPrivate *v = new KTextEditor::ViewPrivate(&doc, nullptr);
         v->setCursorPosition({0, 0});
         v->addSecondaryCursor({1, 0});
@@ -813,7 +830,7 @@ void MulticursorTest::testMultiCopyPaste()
 
 void MulticursorTest::testSelectionTextOrdering()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar\nfoo\nfoo", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\nfoo"), 0, 0);
     view->addSecondaryCursor({1, 0});
     view->addSecondaryCursor({2, 0});
     view->shiftWordRight();
@@ -828,7 +845,7 @@ void MulticursorTest::testSelectionTextOrdering()
 
 void MulticursorTest::testViewClear()
 {
-    CREATE_VIEW_AND_DOC("foo\nbar", 0, 0);
+    auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar"), 0, 0);
     view->addSecondaryCursor({1, 0});
     QCOMPARE(view->secondaryCursors().size(), 1);
     view->clear();
@@ -837,10 +854,10 @@ void MulticursorTest::testViewClear()
 
 void MulticursorTest::testSetGetCursors()
 {
-    using Cursors = QVector<Cursor>;
+    using Cursors = QList<Cursor>;
     // Simple check
     {
-        CREATE_VIEW_AND_DOC("foo\nbar\nfoo\nfoo", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo\nfoo"), 0, 0);
 
         // primary included
         QCOMPARE(view->cursors(), Cursors{Cursor(0, 0)});
@@ -852,12 +869,12 @@ void MulticursorTest::testSetGetCursors()
         QCOMPARE(view->cursorPosition(), Cursor(0, 1));
         // We have no selection
         QVERIFY(!view->selection());
-        QCOMPARE(view->selectionRanges(), QVector<Range>{});
+        QCOMPARE(view->selectionRanges(), QList<Range>{});
     }
 
     // Test duplicate cursor positions
     {
-        CREATE_VIEW_AND_DOC("foo\nbar", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar"), 0, 0);
 
         QCOMPARE(view->cursors(), Cursors{Cursor(0, 0)});
         const Cursors cursors = {{0, 0}, {1, 1}, {0, 0}, {1, 1}};
@@ -877,9 +894,9 @@ void MulticursorTest::testSetGetSelections()
 {
     // Set cursors => press shift+right
     {
-        CREATE_VIEW_AND_DOC("foo\nbar\nfoo", 0, 0);
-        QCOMPARE(view->cursors(), QVector<Cursor>{Cursor(0, 0)});
-        QVector<Cursor> cursors = {{0, 1}, {1, 1}, {2, 1}};
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar\nfoo"), 0, 0);
+        QCOMPARE(view->cursors(), QList<Cursor>{Cursor(0, 0)});
+        QList<Cursor> cursors = {{0, 1}, {1, 1}, {2, 1}};
         view->setCursors(cursors);
         QCOMPARE(view->cursors(), cursors);
         QVERIFY(isSorted(view->cursors()));
@@ -887,7 +904,7 @@ void MulticursorTest::testSetGetSelections()
         QVERIFY(view->selection());
         cursors = {{0, 2}, {1, 2}, {2, 2}};
         QCOMPARE(view->cursors(), cursors);
-        QVector<Range> selections = {Range(0, 1, 0, 2), Range(1, 1, 1, 2), Range(2, 1, 2, 2)};
+        QList<Range> selections = {Range(0, 1, 0, 2), Range(1, 1, 1, 2), Range(2, 1, 2, 2)};
         QCOMPARE(view->selectionRanges(), selections);
         QVERIFY(isSorted(view->selectionRanges()));
         QCOMPARE(view->selectionRange(), selections.front());
@@ -897,24 +914,24 @@ void MulticursorTest::testSetGetSelections()
     // - primary already has selection
     // - try to get selection
     {
-        CREATE_VIEW_AND_DOC("foo\nbar", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar"), 0, 0);
         view->shiftWordRight();
         QVERIFY(view->selection());
         QCOMPARE(view->selectionRange(), Range(0, 0, 0, 3));
 
-        QVector<Cursor> cursors = {{0, 1}, {1, 1}, {2, 1}};
+        QList<Cursor> cursors = {{0, 1}, {1, 1}, {2, 1}};
         view->setCursors(cursors);
         QVERIFY(!view->selection()); // selection is lost
-        auto expectedCursors = QVector<Cursor>{Cursor(0, 1), Cursor(1, 1)};
+        auto expectedCursors = QList<Cursor>{Cursor(0, 1), Cursor(1, 1)};
         QCOMPARE(view->cursors(), expectedCursors);
     }
 
     // Set selections
     {
-        CREATE_VIEW_AND_DOC("foo\nbar", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar"), 0, 0);
 
         QVERIFY(!view->selection());
-        QVector<Range> selections = {Range(0, 0, 0, 1), Range(1, 0, 1, 1)};
+        QList<Range> selections = {Range(0, 0, 0, 1), Range(1, 0, 1, 1)};
         view->setSelections(selections);
         QVERIFY(view->selection());
         QCOMPARE(view->selectionRanges(), selections);
@@ -922,13 +939,13 @@ void MulticursorTest::testSetGetSelections()
 
     // Set overlapping selections
     {
-        CREATE_VIEW_AND_DOC("foo\nbar", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar"), 0, 0);
 
         QVERIFY(!view->selection());
-        QVector<Range> selections = {Range(0, 0, 0, 3), Range(0, 1, 0, 2), Range(0, 0, 0, 1)};
+        QList<Range> selections = {Range(0, 0, 0, 3), Range(0, 1, 0, 2), Range(0, 0, 0, 1)};
         view->setSelections(selections);
         QVERIFY(view->selection());
-        QVector<Range> expectedSelections = {Range(0, 0, 0, 3)};
+        QList<Range> expectedSelections = {Range(0, 0, 0, 3)};
         QCOMPARE(view->selectionRanges(), expectedSelections);
 
         view->setSelections({});
@@ -937,15 +954,17 @@ void MulticursorTest::testSetGetSelections()
 
     // Set selections with invalid range
     {
-        CREATE_VIEW_AND_DOC("foo\nbar", 0, 0);
+        auto [doc, view] = createDocAndView(QStringLiteral("foo\nbar"), 0, 0);
 
         QVERIFY(!view->selection());
-        QVector<Range> selections = {Range(0, 0, 0, 3), Range(1, 0, 1, 1), Range(2, 0, 2, 1)};
+        QList<Range> selections = {Range(0, 0, 0, 3), Range(1, 0, 1, 1), Range(2, 0, 2, 1)};
         view->setSelections(selections);
         QVERIFY(view->selection());
-        QVector<Range> expectedSelections = {Range(0, 0, 0, 3), Range(1, 0, 1, 1)};
+        QList<Range> expectedSelections = {Range(0, 0, 0, 3), Range(1, 0, 1, 1)};
         QCOMPARE(view->selectionRanges(), expectedSelections);
     }
 }
 
+#include "moc_multicursortest.cpp"
+
 // kate: indent-mode cstyle; indent-width 4; replace-tabs on;
