@@ -5,7 +5,6 @@
 */
 
 #include "katetextfolding.h"
-#include "documentcursor.h"
 #include "katedocument.h"
 #include "katetextbuffer.h"
 #include "katetextrange.h"
@@ -361,10 +360,10 @@ int TextFolding::visibleLineToLine(int visibleLine) const
     return line;
 }
 
-QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRangesStartingOnLine(int line) const
+QList<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRangesStartingOnLine(int line) const
 {
     // results vector
-    QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> results;
+    QList<QPair<qint64, TextFolding::FoldingRangeFlags>> results;
 
     // recursively do binary search
     foldingRangesStartingOnLine(results, m_foldingRanges, line);
@@ -373,9 +372,7 @@ QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRange
     return results;
 }
 
-void TextFolding::foldingRangesStartingOnLine(QVector<QPair<qint64, FoldingRangeFlags>> &results,
-                                              const TextFolding::FoldingRange::Vector &ranges,
-                                              int line) const
+void TextFolding::foldingRangesStartingOnLine(QList<QPair<qint64, FoldingRangeFlags>> &results, const TextFolding::FoldingRange::Vector &ranges, int line) const
 {
     // early out for no folds
     if (ranges.isEmpty()) {
@@ -405,7 +402,7 @@ void TextFolding::foldingRangesStartingOnLine(QVector<QPair<qint64, FoldingRange
     }
 }
 
-QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRangesForParentRange(qint64 parentRangeId) const
+QList<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRangesForParentRange(qint64 parentRangeId) const
 {
     // toplevel ranges requested or real parent?
     const FoldingRange::Vector *ranges = nullptr;
@@ -416,7 +413,7 @@ QVector<QPair<qint64, TextFolding::FoldingRangeFlags>> TextFolding::foldingRange
     }
 
     // no ranges => nothing to do
-    QVector<QPair<qint64, FoldingRangeFlags>> results;
+    QList<QPair<qint64, FoldingRangeFlags>> results;
     if (!ranges) {
         return results;
     }
@@ -772,10 +769,8 @@ void TextFolding::importFoldingRanges(const QJsonDocument &folds)
         const KTextEditor::Cursor end(rangeMap[QStringLiteral("endLine")].toInt(), rangeMap[QStringLiteral("endColumn")].toInt());
 
         // check validity (required when loading a possibly broken folding state from disk)
-        if (start >= end
-            || (m_buffer.document() && // <-- unit test katetextbuffertest does not have a KTE::Document assigned
-                (!KTextEditor::DocumentCursor(m_buffer.document(), start).isValidTextPosition()
-                 || !KTextEditor::DocumentCursor(m_buffer.document(), end).isValidTextPosition()))) {
+        auto doc = m_buffer.document();
+        if (start >= end || !doc->isValidTextPosition(start) || !doc->isValidTextPosition(end)) {
             continue;
         }
 
