@@ -10,8 +10,6 @@
 #include "kateglobal.h"
 #include "katemodemanager.h"
 #include "katepartdebug.h"
-#include "katesyntaxmanager.h"
-#include "kateview.h"
 
 #include <QAbstractItemView>
 #include <QApplication>
@@ -1204,5 +1202,3 @@ void KateModeMenuList::updateMenu(KTextEditor::Document *doc)
 {
     m_doc = static_cast<KTextEditor::DocumentPrivate *>(doc);
 }
-
-#include "moc_katemodemenulist.cpp"
