@@ -9,11 +9,11 @@
 #define ONTHEFLYCHECK_H
 
 #include <QList>
-#include <QMap>
 #include <QObject>
 #include <QPair>
 #include <QSet>
 #include <QString>
+#include <map>
 
 #include <sonnet/speller.h>
 
@@ -26,8 +26,6 @@ class BackgroundChecker;
 
 class KateOnTheFlyChecker : public QObject, private KTextEditor::MovingRangeFeedback
 {
-    Q_OBJECT
-
     enum ModificationType { TEXT_INSERTED = 0, TEXT_REMOVED };
 
     typedef QPair<KTextEditor::MovingRange *, QString> SpellCheckItem;
@@ -44,10 +42,11 @@ public:
 
     QPair<KTextEditor::Range, QString> getMisspelledItem(const KTextEditor::Cursor cursor) const;
     QString dictionaryForMisspelledRange(KTextEditor::Range range) const;
+    MovingRangeList installedMovingRanges(KTextEditor::Range range) const;
 
     void clearMisspellingForWord(const QString &word);
 
-public Q_SLOTS:
+public:
     void textInserted(KTextEditor::Document *document, KTextEditor::Range range);
     void textRemoved(KTextEditor::Document *document, KTextEditor::Range range);
 
@@ -65,12 +64,10 @@ protected:
     MisspelledList m_misspelledList;
     ModificationList m_modificationList;
     KTextEditor::DocumentPrivate::OffsetList m_currentDecToEncOffsetList;
-    QMap<KTextEditor::View *, KTextEditor::Range> m_displayRangeMap;
+    std::map<KTextEditor::View *, KTextEditor::Range> m_displayRangeMap;
 
     void freeDocument();
 
-    MovingRangeList installedMovingRanges(KTextEditor::Range range);
-
     void queueLineSpellCheck(KTextEditor::DocumentPrivate *document, int line);
     /**
      * 'range' must be on a single line
@@ -90,8 +87,6 @@ protected:
     bool removeRangeFromSpellCheckQueue(KTextEditor::MovingRange *range);
     void rangeEmpty(KTextEditor::MovingRange *range) override;
     void rangeInvalid(KTextEditor::MovingRange *range) override;
-    void mouseEnteredRange(KTextEditor::MovingRange *range, KTextEditor::View *view) override;
-    void mouseExitedRange(KTextEditor::MovingRange *range, KTextEditor::View *view) override;
     void caretEnteredRange(KTextEditor::MovingRange *range, KTextEditor::View *view) override;
     void caretExitedRange(KTextEditor::MovingRange *range, KTextEditor::View *view) override;
 
@@ -102,7 +97,7 @@ protected:
     void deleteMovingRangeQuickly(KTextEditor::MovingRange *range);
     void stopCurrentSpellCheck();
 
-protected Q_SLOTS:
+protected:
     void performSpellCheck();
     void addToDictionary(const QString &word);
     void addToSession(const QString &word);
