@@ -14,7 +14,6 @@
 #include "katepartdebug.h"
 #include "katerenderer.h"
 #include "katesyntaxmanager.h"
-#include "katetextline.h"
 #include "kateview.h"
 
 #include <KLocalizedString>
@@ -261,7 +260,7 @@ bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_c
     } else if (cmd == QLatin1String("tfold")) {
         return (v->textFolding().newFoldingRange(range.isValid() ? range : v->selectionRange(), Kate::TextFolding::Folded) != -1);
     } else if (cmd == QLatin1String("unfold")) {
-        QVector<QPair<qint64, Kate::TextFolding::FoldingRangeFlags>> startingRanges = v->textFolding().foldingRangesStartingOnLine(v->cursorPosition().line());
+        QList<QPair<qint64, Kate::TextFolding::FoldingRangeFlags>> startingRanges = v->textFolding().foldingRangesStartingOnLine(v->cursorPosition().line());
         bool unfolded = false;
         for (int i = 0; i < startingRanges.size(); ++i) {
             if (startingRanges[i].second & Kate::TextFolding::Folded) {
